==> nb_utils-3.2.11%2B9.tar.gz: lib/src/AppTextField.dart <==
import 'package:flutter/material.dart';
import 'package:nb_utils/nb_utils.dart';

enum TextFieldType { EMAIL, PASSWORD, NAME, ADDRESS, OTHER, PHONE }

class AppTextField extends StatefulWidget {
  final TextEditingController controller;
  final FocusNode focus;
  final FormFieldValidator<String> validator;
  final TextFieldType textFieldType;
  final bool isPassword;
  final bool isValidationRequired;
  final TextCapitalization textCapitalization;
  final TextInputAction textInputAction;
  final Function(String) onFieldSubmitted;
  final Function(String) onChanged;
  final FocusNode nextFocus;
  final TextStyle textStyle;
  final TextAlign textAlign;
  final int maxLines;
  final int minLines;
  final InputDecoration decoration;
  final bool enabled;
  final bool autoFocus;
  final bool readOnly;
  final bool enableSuggestions;
  final int maxLength;
  final Color cursorColor;
  final Widget suffix;
  final TextInputType keyboardType;
  final Iterable<String> autoFillHints;
  final EdgeInsets scrollPadding;
  final double cursorWidth;
  final double cursorHeight;
  final Function onTap;
  final InputCounterWidgetBuilder buildCounter;

  final String errorThisFieldRequired;
  final String errorInvalidEmail;
  final String errorMinimumPasswordLength;

  AppTextField({
    @required this.controller,
    @required this.textFieldType,
    @required this.decoration,
    this.focus,
    this.validator,
    this.isPassword,
    this.buildCounter,
    this.isValidationRequired,
    this.textCapitalization,
    this.textInputAction,
    this.onFieldSubmitted,
    this.nextFocus,
    this.textStyle,
    this.textAlign,
    this.maxLines,
    this.minLines,
    this.enabled,
    this.onChanged,
    this.cursorColor,
    this.suffix,
    this.enableSuggestions,
    this.autoFocus,
    this.readOnly,
    this.maxLength,
    this.keyboardType,
    this.autoFillHints,
    this.scrollPadding,
    this.onTap,
    this.cursorWidth,
    this.cursorHeight,
    this.errorThisFieldRequired,
    this.errorInvalidEmail,
    this.errorMinimumPasswordLength,
  });

  @override
  _AppTextFieldState createState() => _AppTextFieldState();
}

class _AppTextFieldState extends State<AppTextField> {
  bool isPasswordVisible = false;

  @override
  Widget build(BuildContext context) {
    return TextFormField(
      controller: widget.controller,
      obscureText:
          widget.textFieldType == TextFieldType.PASSWORD && !isPasswordVisible,
      validator: widget.isValidationRequired.validate(value: true)
          ? widget.validator != null
              ? widget.validator
              : widget.textFieldType == TextFieldType.EMAIL
                  ? (s) {
                      if (s.trim().isEmpty)
                        return widget.errorThisFieldRequired
                            .validate(value: errorThisFieldRequired);
                      if (!s.trim().validateEmail())
                        return widget.errorInvalidEmail
                            .validate(value: 'Email is invalid');
                      return null;
                    }
                  : widget.textFieldType == TextFieldType.PASSWORD
                      ? (s) {
                          if (s.trim().isEmpty)
                            return widget.errorThisFieldRequired
                                .validate(value: errorThisFieldRequired);
                          if (s.trim().length < passwordLengthGlobal)
                            return widget.errorMinimumPasswordLength.validate(
                                value:
                                    'Minimum password length should be $passwordLengthGlobal');
                          return null;
                        }
                      : widget.textFieldType == TextFieldType.NAME
                          ? (s) {
                              if (s.trim().isEmpty)
                                return widget.errorThisFieldRequired
                                    .validate(value: errorThisFieldRequired);
                              return null;
                            }
                          : null
          : null,
      textCapitalization: widget.textCapitalization != null
          ? widget.textCapitalization
          : widget.textFieldType == TextFieldType.NAME
              ? TextCapitalization.words
              : TextCapitalization.none,
      textInputAction: widget.textInputAction != null
          ? widget.textInputAction
          : widget.textFieldType == TextFieldType.ADDRESS
              ? TextInputAction.newline
              : widget.nextFocus != null
                  ? TextInputAction.next
                  : TextInputAction.done,
      onFieldSubmitted: (s) {
        if (widget.nextFocus != null)
          FocusScope.of(context).requestFocus(widget.nextFocus);

        if (widget.onFieldSubmitted != null) widget.onFieldSubmitted.call(s);
      },
      keyboardType: widget.keyboardType != null
          ? widget.keyboardType
          : widget.textFieldType == TextFieldType.EMAIL
              ? TextInputType.emailAddress
              : widget.textFieldType == TextFieldType.ADDRESS
                  ? TextInputType.multiline
                  : widget.textFieldType == TextFieldType.PASSWORD
                      ? TextInputType.visiblePassword
                      : widget.textFieldType == TextFieldType.PHONE
                          ? TextInputType.number
                          : TextInputType.text,
      decoration: widget.decoration.copyWith(
        suffix: widget.textFieldType == TextFieldType.PASSWORD
            ? widget.suffix != null
                ? widget.suffix
                : Icon(isPasswordVisible
                        ? Icons.visibility
                        : Icons.visibility_off)
                    .onTap(() {
                    isPasswordVisible = !isPasswordVisible;

                    setState(() {});
                  })
            : widget.suffix,
        alignLabelWithHint: true,
      ),
      focusNode: widget.focus,
      style: widget.textStyle,
      textAlign: widget.textAlign ?? TextAlign.start,
      maxLines: widget.maxLines.validate(value: 1),
      minLines: widget.minLines.validate(value: 1),
      autofocus: widget.autoFocus ?? false,
      enabled: widget.enabled,
      onChanged: widget.onChanged,
      cursorColor: widget.cursorColor,
      readOnly: widget.readOnly,
      maxLength: widget.maxLength,
      enableSuggestions: widget.enableSuggestions.validate(value: true),
      autofillHints: widget.autoFillHints,
      scrollPadding: widget.scrollPadding ?? EdgeInsets.all(20),
      cursorWidth: widget.cursorWidth.validate(value: 2.0),
      cursorHeight: widget.cursorHeight,
      cursorRadius: Radius.circular(4),
      onTap: widget.onTap,
      buildCounter: widget.buildCounter,
      scrollPhysics: BouncingScrollPhysics(),
    );
  }
}

==> nb_utils-3.3.0%2B9.tar.gz: lib/src/AppTextField.dart <==
import 'package:flutter/material.dart';
import 'package:nb_utils/nb_utils.dart';

enum TextFieldType { EMAIL, PASSWORD, NAME, ADDRESS, OTHER, PHONE }

class AppTextField extends StatefulWidget {
  final TextEditingController controller;
  final FocusNode focus;
  final FormFieldValidator<String> validator;
  final TextFieldType textFieldType;
  final bool isPassword;
  final bool isValidationRequired;
  final TextCapitalization textCapitalization;
  final TextInputAction textInputAction;
  final Function(String) onFieldSubmitted;
  final Function(String) onChanged;
  final FocusNode nextFocus;
  final TextStyle textStyle;
  final TextAlign textAlign;
  final int maxLines;
  final int minLines;
  final InputDecoration decoration;
  final bool enabled;
  final bool autoFocus;
  final bool readOnly;
  final bool enableSuggestions;
  final int maxLength;
  final Color cursorColor;
  final Widget suffix;
  final Color suffixIconColor;
  final TextInputType keyboardType;
  final Iterable<String> autoFillHints;
  final EdgeInsets scrollPadding;
  final double cursorWidth;
  final double cursorHeight;
  final Function onTap;
  final InputCounterWidgetBuilder buildCounter;

  final String errorThisFieldRequired;
  final String errorInvalidEmail;
  final String errorMinimumPasswordLength;

  AppTextField({
    @required this.controller,
    @required this.textFieldType,
    @required this.decoration,
    this.focus,
    this.validator,
    this.isPassword,
    this.buildCounter,
    this.isValidationRequired,
    this.textCapitalization,
    this.textInputAction,
    this.onFieldSubmitted,
    this.nextFocus,
    this.textStyle,
    this.textAlign,
    this.maxLines,
    this.minLines,
    this.enabled,
    this.onChanged,
    this.cursorColor,
    this.suffix,
    this.suffixIconColor,
    this.enableSuggestions,
    this.autoFocus,
    this.readOnly,
    this.maxLength,
    this.keyboardType,
    this.autoFillHints,
    this.scrollPadding,
    this.onTap,
    this.cursorWidth,
    this.cursorHeight,
    this.errorThisFieldRequired,
    this.errorInvalidEmail,
    this.errorMinimumPasswordLength,
  });

  @override
  _AppTextFieldState createState() => _AppTextFieldState();
}

class _AppTextFieldState extends State<AppTextField> {
  bool isPasswordVisible = false;

  @override
  Widget build(BuildContext context) {
    return TextFormField(
      controller: widget.controller,
      obscureText:
          widget.textFieldType == TextFieldType.PASSWORD && !isPasswordVisible,
      validator: widget.isValidationRequired.validate(value: true)
          ? widget.validator != null
              ? widget.validator
              : widget.textFieldType == TextFieldType.EMAIL
                  ? (s) {
                      if (s.trim().isEmpty)
                        return widget.errorThisFieldRequired
                            .validate(value: errorThisFieldRequired);
                      if (!s.trim().validateEmail())
                        return widget.errorInvalidEmail
                            .validate(value: 'Email is invalid');
                      return null;
                    }
                  : widget.textFieldType == TextFieldType.PASSWORD
                      ? (s) {
                          if (s.trim().isEmpty)
                            return widget.errorThisFieldRequired
                                .validate(value: errorThisFieldRequired);
                          if (s.trim().length < passwordLengthGlobal)
                            return widget.errorMinimumPasswordLength.validate(
                                value:
                                    'Minimum password length should be $passwordLengthGlobal');
                          return null;
                        }
                      : widget.textFieldType == TextFieldType.NAME
                          ? (s) {
                              if (s.trim().isEmpty)
                                return widget.errorThisFieldRequired
                                    .validate(value: errorThisFieldRequired);
                              return null;
                            }
                          : null
          : null,
      textCapitalization: widget.textCapitalization != null
          ? widget.textCapitalization
          : widget.textFieldType == TextFieldType.NAME
              ? TextCapitalization.words
              : TextCapitalization.none,
      textInputAction: widget.textInputAction != null
          ? widget.textInputAction
          : widget.textFieldType == TextFieldType.ADDRESS
              ? TextInputAction.newline
              : widget.nextFocus != null
                  ? TextInputAction.next
                  : TextInputAction.done,
      onFieldSubmitted: (s) {
        if (widget.nextFocus != null)
          FocusScope.of(context).requestFocus(widget.nextFocus);

        if (widget.onFieldSubmitted != null) widget.onFieldSubmitted.call(s);
      },
      keyboardType: widget.keyboardType != null
          ? widget.keyboardType
          : widget.textFieldType == TextFieldType.EMAIL
              ? TextInputType.emailAddress
              : widget.textFieldType == TextFieldType.ADDRESS
                  ? TextInputType.multiline
                  : widget.textFieldType == TextFieldType.PASSWORD
                      ? TextInputType.visiblePassword
                      : widget.textFieldType == TextFieldType.PHONE
                          ? TextInputType.number
                          : TextInputType.text,
      decoration: widget.decoration.copyWith(
        suffix: widget.textFieldType == TextFieldType.PASSWORD
            ? widget.suffix != null
                ? widget.suffix
                : Icon(
                        isPasswordVisible
                            ? Icons.visibility
                            : Icons.visibility_off,
                        color: widget.suffixIconColor ??
                            Theme.of(context).iconTheme.color)
                    .onTap(() {
                    isPasswordVisible = !isPasswordVisible;

                    setState(() {});
                  })
            : widget.suffix,
      ),
      focusNode: widget.focus,
      style: widget.textStyle ?? primaryTextStyle(),
      textAlign: widget.textAlign ?? TextAlign.start,
      maxLines: widget.maxLines.validate(value: 1),
      minLines: widget.minLines.validate(value: 1),
      autofocus: widget.autoFocus ?? false,
      enabled: widget.enabled,
      onChanged: widget.onChanged,
      cursorColor: widget.cursorColor ?? Theme.of(context).cursorColor,
      readOnly: widget.readOnly.validate(),
      maxLength: widget.maxLength,
      enableSuggestions: widget.enableSuggestions.validate(value: true),
      autofillHints: widget.autoFillHints,
      scrollPadding: widget.scrollPadding ?? EdgeInsets.all(20),
      cursorWidth: widget.cursorWidth.validate(value: 2.0),
      cursorHeight: widget.cursorHeight,
      cursorRadius: Radius.circular(4),
      onTap: widget.onTap,
      buildCounter: widget.buildCounter,
      scrollPhysics: BouncingScrollPhysics(),
    );
  }
}
